if(!self.define){let e,s={};const n=(n,i)=>(n=new URL(n+".js",i).href,s[n]||new Promise(s=>{if("document"in self){const e=document.createElement("script");e.src=n,e.onload=s,document.head.appendChild(e)}else e=n,importScripts(n),s()}).then(()=>{let e=s[n];if(!e)throw new Error(`Module ${n} didn’t register its module`);return e}));self.define=(i,t)=>{const r=e||("document"in self?document.currentScript.src:"")||location.href;if(s[r])return;let o={};const c=e=>n(e,r),a={module:{uri:r},exports:o,require:c};s[r]=Promise.all(i.map(e=>a[e]||c(e))).then(e=>(t(...e),o))}}define(["./workbox-354287e6"],function(e){"use strict";self.skipWaiting(),e.clientsClaim(),e.precacheAndRoute([{url:"ws-test.html",revision:"def76ee9f022847f9bffec8689aa64b0"},{url:"registerSW.js",revision:"402b66900e731ca748771b6fc5e7a068"},{url:"index.html",revision:"8bce81097411ee466270b705139926e2"},{url:"assets/main-DNLFcyLu.css",revision:null},{url:"assets/main-D6N-xSDs.js",revision:null},{url:"apple-touch-icon.png",revision:"44db7a22f4fd4d1bf19abbd68b731a07"},{url:"manifest.webmanifest",revision:"f69a01b0bb8e5290e4b3b3c0c281e460"}],{}),e.cleanupOutdatedCaches(),e.registerRoute(new e.NavigationRoute(e.createHandlerBoundToURL("index.html"))),e.registerRoute(({request:e})=>"navigate"===e.mode,new e.NetworkFirst({cacheName:"navigation-cache",networkTimeoutSeconds:5,plugins:[new e.ExpirationPlugin({maxEntries:5,maxAgeSeconds:60})]}),"GET"),e.registerRoute(/\/assets\/.+\.[a-f0-9]{8}\.(js|css|woff2?)$/i,new e.CacheFirst({cacheName:"immutable-assets",plugins:[new e.ExpirationPlugin({maxEntries:200,maxAgeSeconds:31536e3})]}),"GET")});
